abacusai.dataset_version — AbacusAI documentation

# `abacusai.dataset_version`

## Module Contents

### Classes

`DatasetVersion` | A specific version of a dataset

class abacusai.dataset_version.DatasetVersion(client, datasetVersion=None, status=None, datasetId=None, size=None, rowCount=None, createdAt=None, error=None, invalidRecords=None, incrementalQueriedAt=None, uploadId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A specific version of a dataset

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - datasetVersion (str) – The unique identifier of the dataset version.

    - status (str) – The current status of the dataset version

    - datasetId (str) – A reference to the Dataset this dataset version belongs to.

    - size (int) – The size in bytes of the file.

    - rowCount (int) – Number of rows in the dataset version.

    - createdAt (str) – The timestamp this dataset version was created.

    - error (str) – If status is FAILED, this field will be populated with an error.

    - invalidRecords (str) –

    - incrementalQueriedAt (str) – If the dataset version is from an incremental dataset, this is the last entry of timestamp column when the dataset version was created.

    - uploadId (str) – If the dataset version is being uploaded, this the reference to the Upload

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      DatasetVersion

  describe()

    Retrieves a full description of the specified dataset version, with attributes such as its ID, name, source type, etc.

    Parameters:

      dataset_version (str) – The unique ID associated with the dataset version.

    Returns:

      The dataset version.

    Return type:

      DatasetVersion

  wait_for_import(timeout=900)

    A waiting call until dataset version is imported.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_for_inspection(timeout=None)

    A waiting call until dataset version is completely inspected.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the dataset version.

    Returns:

      A string describing the status of a dataset version (importing, inspecting, complete, etc.).

    Return type:

      str